==> beans-ddi-lifecycle-1.0.0-20130130.205259-2-sources.jar: org/openmetadata/beans/ddi/lifecycle/logicalproduct/VariableBean.java <==
package org.openmetadata.beans.ddi.lifecycle.logicalproduct;

import org.openmetadata.beans.ddi.lifecycle.adt.ReferenceSet;
import org.openmetadata.beans.ddi.lifecycle.conceptualcomponent.ConceptBean;
import org.openmetadata.beans.ddi.lifecycle.conceptualcomponent.UniverseBean;
import org.openmetadata.beans.ddi.lifecycle.datacollection.SequenceBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.CodeValueBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.SchemeItemBean;
import org.openmetadata.ddi_3_1.util.DdiClass;

public interface VariableBean extends SchemeItemBean<VariableSchemeBean> {
	
	public final static DdiClass ddiClass = DdiClass.Variable;
	
	boolean getIsTemporal();

	void setIsTemporal(boolean isTemporal);

	boolean isSetIsTemporal();

	boolean getIsGeographic();

	void setIsGeographic(boolean isGeographic);

	boolean isSetIsGeographic();

	boolean getIsWeight();

	void setIsWeight(boolean isWeight);

	boolean isSetIsWeight();

	VariableGroupBean[] getReferringVariableGroups();

	ReferenceSet<UniverseBean> getUniverseList();

	boolean isSetConcept();

	void setConcept(ConceptBean concept) ;

	void unsetConcept();

	ConceptBean getConcept();

	String getConceptUrn();

	boolean isSetSequence();

	void setSequence(SequenceBean sequence);

	void unsetSequence();

	SequenceBean getSequence();

	String getSequenceUrn();

	String getResponseUnit();

	void setResponseUnit(String responseUnit);

	boolean isSetResponseUnit();

	CodeValueBean getAnalysisUnit();

	boolean isSetAnalysisUnit();

	VariableRepresentationBean getRepresentation();

	boolean isSetRepresentation();

}

==> beans-ddi-lifecycle-1.0.0-20130314.142147-3-sources.jar: org/openmetadata/beans/ddi/lifecycle/logicalproduct/VariableBean.java <==
package org.openmetadata.beans.ddi.lifecycle.logicalproduct;

import org.openmetadata.beans.ddi.lifecycle.adt.ReferenceSet;
import org.openmetadata.beans.ddi.lifecycle.conceptualcomponent.ConceptBean;
import org.openmetadata.beans.ddi.lifecycle.conceptualcomponent.UniverseBean;
import org.openmetadata.beans.ddi.lifecycle.datacollection.QuestionItemBean;
import org.openmetadata.beans.ddi.lifecycle.datacollection.SequenceBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.CodeValueBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.SchemeItemBean;
import org.openmetadata.ddi_3_1.util.DdiClass;

public interface VariableBean extends SchemeItemBean<VariableSchemeBean> {
	
	public final static DdiClass ddiClass = DdiClass.Variable;
	
	boolean getIsTemporal();

	void setIsTemporal(boolean isTemporal);

	boolean isSetIsTemporal();

	boolean getIsGeographic();

	void setIsGeographic(boolean isGeographic);

	boolean isSetIsGeographic();

	boolean getIsWeight();

	void setIsWeight(boolean isWeight);

	boolean isSetIsWeight();

	VariableGroupBean[] getReferringVariableGroups();

	ReferenceSet<UniverseBean> getUniverseList();

	boolean isSetConcept();

	void setConcept(ConceptBean concept) ;

	void unsetConcept();

	ConceptBean getConcept();

	String getConceptUrn();
	
	boolean isSetQuestionItem();
	
	/**
	 * Setting a question will clear the existing sequence.
	 * @param question
	 */
	void setQuestionItem(QuestionItemBean question);
	
	void unsetQuestionItem();
	
	QuestionItemBean getQuestionItem();

	boolean isSetSequence();

	/**
	 * Setting a question will clear the existing question.
	 * @param question
	 */
	void setSequence(SequenceBean sequence);

	void unsetSequence();

	SequenceBean getSequence();

	String getSequenceUrn();

	String getResponseUnit();

	void setResponseUnit(String responseUnit);

	boolean isSetResponseUnit();

	CodeValueBean getAnalysisUnit();

	boolean isSetAnalysisUnit();

	VariableRepresentationBean getRepresentation();

	boolean isSetRepresentation();

}
